@@ -19,7 +19,9 @@ def main():
     p.add_argument("ref", help="filename to compare against")
     p.add_argument("root", help="top-level directory to search under")
     p.add_argument("-exe", help="program to compare with")
-    p.add_argument("-n", "--dryrun", help="just report files that are different", action="store_true")
+    p.add_argument(
+        "-n", "--dryrun", help="just report files that are different", action="store_true"
+    )
     p = p.parse_args()
 
     level = logging.INFO if p.dryrun else None
@@ -28,6 +30,9 @@ def main():
     ref = Path(p.ref).expanduser().resolve()
 
     for file in mu.files_to_diff(p.root, ref):
+        if "_deps" in file.parts:
+            # CMake FetchContent (like Git submodule)
+            continue
         if p.dryrun:
             print(file, "!=", ref)
         else:
